# ChessTab - About

ChessTab lists the games on a database and displays the scores of selected games.

This is ChessTab-4.0.1

python setup.py install will have installed these packages:

- solentware-base-4.0
- chessql-1.2.1
- chesstab-4.0.1
- pgn-read-1.3.1
- solentware-grid-2.0
- solentware-misc-1.2
- uci-net-1.2

ChessTab uses features introduced at Python3.4 but declared stable at Python3.6.

Dependencies:

> Python3.6, or later versions when available, must be installed to run ChessTab.

> tkinter, part of Python, must be installed to run ChessTab. Sometimes this is installed separately.

> One of sqlite3, apsw, or bsddb3, must be installed to run ChessTab. sqlite3 is part of Python, but sometimes is installed separately. apsw and bsddb3 are packages for Python, so must be installed separately.